"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.usePrevious = void 0;
const react_1 = require("react");
/**
 * usePrevious hook
 *
 * This hook is used to track the previous version of a variable from a prior
 * render for the purposes of conditionally updating aspects of a component based on
 * whether particular variables have changed.
 */
/* eslint-disable-next-line @typescript-eslint/ban-types */
const usePrevious = (value) => {
    // The ref object is a generic container whose current property is mutable ...
    // ... and can hold any value, similar to an instance property on a class
    const ref = (0, react_1.useRef)();
    // Store current value in ref
    (0, react_1.useEffect)(() => {
        ref.current = value;
    }, [value]); // Only re-run if value changes
    // Return previous value (happens before update in useEffect above)
    return ref.current;
};
exports.usePrevious = usePrevious;
