"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ChannelValue = void 0;
const react_1 = __importStar(require("react"));
const react_native_1 = require("react-native");
const react_native_paper_1 = require("react-native-paper");
const typography_1 = require("../typography");
const icon_1 = require("../icon");
const utility_1 = require("../utility");
const prefixUnitWhitelist = ['$'];
const suffixUnitWhitelist = ['%', '℉', '°F', '℃', '°C', '°'];
const defaultStyles = react_native_1.StyleSheet.create({
    root: {
        maxWidth: '100%',
        flexDirection: 'row',
        alignItems: 'center',
    },
});
/**
 * [ChannelValue](https://brightlayer-ui-components.github.io/react-native/?path=/info/components-documentation--channel-value) component
 *
 * Used to show a stylized value and its units.
 * You may also include an icon.
 */
const ChannelValue = (props) => {
    const { value, fontSize = 16, icon, iconColor, iconSize, color, units, unitSpace = 'auto', prefix = false, styles = {}, style, theme: themeOverride, ...viewProps } = props;
    const theme = (0, react_native_paper_1.useTheme)(themeOverride);
    const getColor = (0, react_1.useCallback)(() => {
        if (!color)
            return theme.colors.text;
        return color;
    }, [color, theme]);
    const getIcon = (0, react_1.useCallback)(() => {
        if (icon) {
            return (react_1.default.createElement(react_native_1.View, { style: [{ marginRight: Math.round(fontSize / 3) }] },
                react_1.default.createElement(icon_1.Icon, { source: icon, size: iconSize || fontSize, color: iconColor || getColor() })));
        }
    }, [icon, fontSize, getColor, iconColor, iconSize]);
    const getUnits = (0, react_1.useCallback)((spacerLocation) => {
        if (units) {
            return (react_1.default.createElement(react_1.default.Fragment, null,
                ((spacerLocation === 'before' && unitSpace === 'show') ||
                    (spacerLocation === 'before' &&
                        unitSpace === 'auto' &&
                        !suffixUnitWhitelist.includes(units))) && react_1.default.createElement(utility_1.Spacer, { flex: 0, width: fontSize / 4 }),
                react_1.default.createElement(typography_1.Body1, { font: 'light', fontSize: fontSize, style: [
                        {
                            color: getColor(),
                        },
                        styles.units,
                    ] }, units),
                ((spacerLocation === 'after' && unitSpace === 'show') ||
                    (spacerLocation === 'after' &&
                        unitSpace === 'auto' &&
                        !prefixUnitWhitelist.includes(units))) && react_1.default.createElement(utility_1.Spacer, { flex: 0, width: fontSize / 4 })));
        }
    }, [units, fontSize, getColor, styles, unitSpace]);
    const prefixUnits = (0, react_1.useCallback)(() => {
        if ((!react_native_1.I18nManager.isRTL && prefix) || (react_native_1.I18nManager.isRTL && !prefix)) {
            return getUnits('after');
        }
    }, [prefix, getUnits]);
    const suffixUnits = (0, react_1.useCallback)(() => {
        if ((react_native_1.I18nManager.isRTL && prefix) || (!react_native_1.I18nManager.isRTL && !prefix)) {
            return getUnits('before');
        }
    }, [prefix, getUnits]);
    return (react_1.default.createElement(react_native_1.View, { style: [defaultStyles.root, styles.root, style], ...viewProps },
        getIcon(),
        react_1.default.createElement(typography_1.Body1, { numberOfLines: 1, ellipsizeMode: 'tail', testID: 'text-wrapper', fontSize: fontSize, style: [{ color: getColor() }] },
            prefixUnits(),
            react_1.default.createElement(typography_1.Subtitle1, { fontSize: fontSize, style: [{ color: getColor() }, styles.value] }, value),
            suffixUnits())));
};
exports.ChannelValue = ChannelValue;
