"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.DrawerBody = void 0;
const react_1 = __importDefault(require("react"));
const react_native_1 = require("react-native");
const drawer_nav_group_1 = require("./drawer-nav-group");
const utilities_1 = require("./utilities");
const makeStyles = () => react_native_1.StyleSheet.create({
    root: {},
});
/**
 * [DrawerBody](https://brightlayer-ui-components.github.io/react-native/?path=/info/components-documentation--drawer) component
 *
 * The DrawerBody is a wrapper for the main content of your navigation Drawer. This section sits between
 * the DrawerHeader (or optional DrawerSubheader) and the DrawerFooter. This part of the drawer should hold
 * your main navigation elements (either using the `items` prop or by passing in DrawerNavGroup and DrawerNavItem children
 * declaratively).
 */
const DrawerBody = (props) => {
    const { 
    // Inheritable Props
    /* eslint-disable @typescript-eslint/no-unused-vars */
    activeItemBackgroundColor, activeItemBackgroundShape, activeItemFontColor, activeItemIconColor, backgroundColor, chevron, collapseIcon, disableActiveItemParentStyles, divider, expandIcon, hidePadding, itemFontColor, itemIconColor, nestedBackgroundColor, nestedDivider, theme: themeOverride, 
    /* eslint-enable @typescript-eslint/no-unused-vars */
    // DrawerBody-specific props
    styles = {}, 
    // Other ScrollView Props
    style, children: bodyChildren, ...scrollProps } = props;
    const children = react_1.default.Children.toArray(bodyChildren);
    const defaultStyles = makeStyles();
    return (react_1.default.createElement(react_native_1.ScrollView, { style: [defaultStyles.root, styles.root, style], ...scrollProps }, children.map((child, index) => {
        if (!child)
            return null;
        if (child.type && child.type.displayName !== 'DrawerNavGroup')
            return child;
        return (react_1.default.createElement(drawer_nav_group_1.DrawerNavGroup, { key: `NavGroup_${index}`, ...child.props, ...(0, utilities_1.inheritSharedProps)(props, child.props) }));
    })));
};
exports.DrawerBody = DrawerBody;
exports.DrawerBody.displayName = 'DrawerBody';
