"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.DrawerHeader = void 0;
const react_1 = __importStar(require("react"));
const react_native_1 = require("react-native");
const typography_1 = require("../typography");
const react_native_paper_1 = require("react-native-paper");
const react_native_safe_area_context_1 = require("react-native-safe-area-context");
const useHeaderDimensions_1 = require("../__hooks__/useHeaderDimensions");
const icon_1 = require("../icon");
const shared_1 = require("../utility/shared");
const font_scale_context_1 = require("../__contexts__/font-scale-context");
const makeStyles = (props, theme, insets, height, fontScale) => react_native_1.StyleSheet.create({
    root: {
        paddingTop: insets.top,
        backgroundColor: props.backgroundColor || (0, shared_1.getPrimary500)(theme) || theme.colors.primary,
        height: height,
    },
    icon: {
        marginLeft: 16,
        height: 56 * fontScale,
        width: 40 * fontScale,
        justifyContent: 'center',
    },
    content: {
        flexDirection: 'row',
        paddingLeft: insets.left,
    },
    textContent: {
        flexDirection: 'column',
        paddingVertical: 4 * fontScale,
        paddingLeft: 16,
        flex: 1,
        height: '100%',
    },
    title: {
        color: props.fontColor || theme.colors.surface,
        lineHeight: 30,
    },
    subtitle: {
        color: props.fontColor || theme.colors.surface,
        lineHeight: 16,
        marginTop: -2 * fontScale,
    },
    backgroundImageWrapper: {
        position: 'absolute',
        top: 0,
        left: 0,
        bottom: 0,
        right: 0,
        opacity: props.backgroundOpacity,
    },
    backgroundImage: {
        width: '100%',
        height: '100%',
        resizeMode: 'cover',
    },
});
/**
 * [DrawerHeader](https://brightlayer-ui-components.github.io/react-native/?path=/info/components-documentation--drawer) component
 *
 * The DrawerHeader holds the content at the top of your navigation Drawer. You can supply a title and subtitle to
 * use the default styles, or you can supply your own custom titleContent to render. This section will always be pinned
 * at the top of the Drawer.
 */
const DrawerHeader = (props) => {
    const { title, subtitle, titleContent, backgroundImage, fontColor, icon, onIconPress, 
    // eslint-disable-next-line @typescript-eslint/no-unused-vars
    backgroundOpacity, theme: themeOverride, styles = {}, style, ...viewProps } = props;
    const theme = (0, react_native_paper_1.useTheme)(themeOverride);
    const insets = (0, react_native_safe_area_context_1.useSafeAreaInsets)();
    const { REGULAR_HEIGHT } = (0, useHeaderDimensions_1.useHeaderDimensions)();
    const { disableScaling } = (0, font_scale_context_1.useFontScaleSettings)();
    const fontScale = (0, font_scale_context_1.useFontScale)();
    const defaultStyles = makeStyles(props, theme, insets, REGULAR_HEIGHT, fontScale);
    const getIcon = (0, react_1.useCallback)(() => {
        if (icon) {
            return (react_1.default.createElement(react_native_1.View, { style: [defaultStyles.icon, styles.icon] },
                react_1.default.createElement(react_native_1.TouchableOpacity, { testID: 'drawer-header-navigation', onPress: onIconPress, style: { padding: 8, marginLeft: -8 }, disabled: !onIconPress },
                    react_1.default.createElement(icon_1.Icon, { source: icon, size: 24, color: fontColor || 'white', allowFontScaling: !disableScaling }))));
        }
    }, [defaultStyles, styles, icon, fontColor, onIconPress]);
    const getHeaderContent = (0, react_1.useCallback)(() => titleContent || (react_1.default.createElement(react_native_1.View, { style: [defaultStyles.textContent, styles.textContent] },
        react_1.default.createElement(typography_1.H6, { style: [defaultStyles.title, styles.title], numberOfLines: 1 }, title),
        react_1.default.createElement(typography_1.Subtitle1, { font: 'light', style: [defaultStyles.subtitle, styles.subtitle], numberOfLines: 1 }, subtitle))), [title, subtitle, titleContent, defaultStyles, styles]);
    const getBackgroundImage = (0, react_1.useCallback)(() => {
        if (backgroundImage) {
            return (react_1.default.createElement(react_native_1.View, { style: [defaultStyles.backgroundImageWrapper, styles.backgroundImageWrapper] },
                react_1.default.createElement(react_native_1.Image, { source: backgroundImage, resizeMethod: 'resize', 
                    // @ts-ignore typescript is being weird about the backgroundImage style type
                    style: [defaultStyles.backgroundImage, styles.backgroundImage] })));
        }
    }, [backgroundImage, defaultStyles, styles]);
    return (react_1.default.createElement(react_native_1.View, { style: [defaultStyles.root, styles.root, style], ...viewProps },
        getBackgroundImage(),
        react_1.default.createElement(react_native_1.View, { style: [defaultStyles.content, styles.content] },
            icon && getIcon(),
            getHeaderContent()),
        react_1.default.createElement(react_native_paper_1.Divider, null)));
};
exports.DrawerHeader = DrawerHeader;
exports.DrawerHeader.displayName = 'DrawerHeader';
exports.DrawerHeader.defaultProps = {
    backgroundOpacity: 0.3,
};
