"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.DrawerNavItem = void 0;
const react_1 = __importStar(require("react"));
const react_native_1 = require("react-native");
const info_list_item_1 = require("../info-list-item");
const react_native_paper_1 = require("react-native-paper");
const usePrevious_1 = require("../__hooks__/usePrevious");
const color_1 = __importDefault(require("color"));
const MaterialIcons_1 = __importDefault(require("react-native-vector-icons/MaterialIcons"));
const drawer_context_1 = require("./context/drawer-context");
const nav_group_context_1 = require("./context/nav-group-context");
const utilities_1 = require("./utilities");
const Colors = __importStar(require("@brightlayer-ui/colors"));
const react_native_collapsible_1 = __importDefault(require("react-native-collapsible"));
const react_native_safe_area_context_1 = require("react-native-safe-area-context");
const icon_1 = require("../icon");
const shared_1 = require("../utility/shared");
const font_scale_context_1 = require("../__contexts__/font-scale-context");
// First nested item has no additional indentation.  All items start with 16px indentation.
const calcNestedPadding = (depth, insets) => insets.left + (depth > 0 ? (depth - 1) * 32 : 0);
const makeStyles = (props, theme, fontScale) => {
    // Primary color manipulation
    const fivePercentOpacityPrimary = (0, color_1.default)((0, shared_1.getPrimary500)(theme) || theme.colors.primary)
        .alpha(0.05)
        .string();
    const twentyPercentOpacityPrimary = (0, color_1.default)((0, shared_1.getPrimary500)(theme) || theme.colors.primary)
        .alpha(0.2)
        .string();
    const { 
    // Shared style props
    activeItemBackgroundColor = !theme.dark ? fivePercentOpacityPrimary : twentyPercentOpacityPrimary, activeItemBackgroundShape = 'square', backgroundColor, depth, nestedBackgroundColor = theme.dark ? Colors.darkBlack[100] : theme.colors.background, // TODO: don't hardcode?
     } = props;
    return react_native_1.StyleSheet.create({
        root: {
            backgroundColor: depth ? nestedBackgroundColor : backgroundColor || 'transparent',
        },
        activeBackground: {
            backgroundColor: activeItemBackgroundColor,
            zIndex: 0,
            position: 'absolute',
            height: '100%',
            width: activeItemBackgroundShape === 'square' ? '100%' : '97%',
            left: 0,
            top: 0,
            borderTopRightRadius: activeItemBackgroundShape === 'square' ? 0 : 24 * fontScale,
            borderBottomRightRadius: activeItemBackgroundShape === 'square' ? 0 : 24 * fontScale,
        },
        expandIcon: {
            display: 'flex',
            alignItems: 'center',
            marginLeft: 16,
        },
        flipIcon: {
            transform: [{ scaleX: -1 }],
        },
    });
};
/**
 * [DrawerNavItem](https://brightlayer-ui-components.github.io/react-native/?path=/info/components-documentation--drawer) component
 *
 * The DrawerNavItem represents a single navigation item in the Drawer, usually a link to some route
 * in your application, but could also be used for static actions like login or logout. DrawerNavItems
 * can be nested (either declaratively by passing children or through the `items` prop). DrawerNavItems
 * are ultimately rendered as an InfoListItem element.
 *
 * When used inside of a DrawerNavGroup, certain props of the DrawerNavItem (`depth`, `isInActiveTree`, and `notifyActiveParent`)
 * are managed automatically for you.
 */
const DrawerNavItem = (props) => {
    // Destructure the props
    const { theme: themeOverride, ...otherProps } = props;
    const theme = (0, react_native_paper_1.useTheme)(themeOverride);
    const fontScale = (0, font_scale_context_1.useFontScale)();
    const { disableScaling, maxScale, minScale } = (0, font_scale_context_1.useFontScaleSettings)();
    const defaultStyles = makeStyles(props, theme, fontScale);
    const { activeItem, onItemSelect } = (0, drawer_context_1.useDrawerContext)();
    const { activeHierarchy } = (0, nav_group_context_1.useNavGroupContext)();
    const previousActive = (0, usePrevious_1.usePrevious)(activeItem || '');
    // approximating primary[200] but we don't have access to it directly from the theme
    const lightenedPrimary = (0, color_1.default)((0, shared_1.getPrimary500)(theme) || theme.colors.primary)
        .lighten(0.83)
        .desaturate(0.39)
        .string();
    const { 
    // Shared style props
    activeItemBackgroundColor /* eslint-disable-line @typescript-eslint/no-unused-vars */, activeItemBackgroundShape /* eslint-disable-line @typescript-eslint/no-unused-vars */, activeItemFontColor = !theme.dark ? theme.colors.primary : lightenedPrimary, activeItemIconColor = !theme.dark ? theme.colors.primary : lightenedPrimary, backgroundColor /* eslint-disable-line @typescript-eslint/no-unused-vars */, chevron /* eslint-disable-line @typescript-eslint/no-unused-vars */, collapseIcon = { family: 'material', name: props.depth ? 'arrow-drop-up' : 'expand-less' }, disableActiveItemParentStyles = false, divider, expandIcon = { family: 'material', name: props.depth ? 'arrow-drop-down' : 'expand-more' }, hidePadding, itemFontColor = theme.colors.text, itemIconColor = theme.colors.text, nestedBackgroundColor /* eslint-disable-line @typescript-eslint/no-unused-vars */, nestedDivider, 
    // Drawer Nav Item specific props
    children, styles = {}, depth = 0, hidden, icon: itemIcon, 
    // InfoListItemProps = {} as BLUIInfoListItemProps,
    isInActiveTree, itemID, items, notifyActiveParent = () => { }, onPress, rightComponent = props.chevron && !props.items && !props.children ? (react_1.default.createElement(MaterialIcons_1.default, { name: 'chevron-right', size: 24, color: theme.colors.text, style: react_native_1.I18nManager.isRTL ? defaultStyles.flipIcon : {}, allowFontScaling: !disableScaling, maxFontSizeMultiplier: maxScale, minimumFontScale: minScale })) : undefined, statusColor, subtitle: itemSubtitle, title: itemTitle,
    // other View props
     } = otherProps;
    const insets = (0, react_native_safe_area_context_1.useSafeAreaInsets)();
    const [expanded, setExpanded] = (0, react_1.useState)(isInActiveTree); // isInActiveTree: there is a bug in the react-native-collapsible that incorrectly calculates the initial panel height when using nested collapse panels
    const active = activeItem === itemID;
    const hasAction = Boolean(onItemSelect || onPress || (items && items.length > 0) || Boolean(children));
    // only allow icons for the top level items
    const icon = !depth ? itemIcon : undefined;
    const showDivider = depth > 0 ? (nestedDivider !== undefined ? nestedDivider : false) : divider !== undefined ? divider : false;
    // When the activeItem changes, update our expanded state
    // Temporarily disabling this auto-expand behavior due to a bug in the react-native-collapsible with calculating the correct starting height
    // useEffect(() => {
    //     if (isInActiveTree && !expanded) {
    //         setExpanded(true);
    //     }
    // }, [isInActiveTree]); // Only update if the active tree changes (not after manual expand/collapse action)
    // If the active item changes
    (0, react_1.useEffect)(() => {
        if (activeItem === itemID && previousActive !== itemID) {
            // notify the parent that it should now be in the active tree
            notifyActiveParent([itemID]);
        }
    }, [activeItem, notifyActiveParent]);
    // Handle click callbacks
    const onPressAction = (0, react_1.useCallback)(() => {
        if (onItemSelect) {
            onItemSelect(itemID);
        }
        if (onPress) {
            onPress();
        }
        else if ((items && items.length > 0) || Boolean(children)) {
            setExpanded(!expanded);
        }
    }, [onItemSelect, onPress, itemID, items, expanded, setExpanded, children]);
    const getActionComponent = (0, react_1.useCallback)(() => {
        if (!items && !children) {
            return null;
        }
        return (react_1.default.createElement(react_native_1.View, { style: [defaultStyles.expandIcon, styles.expandIcon] },
            react_1.default.createElement(icon_1.Icon, { source: collapseIcon && expanded ? collapseIcon : expandIcon, size: 24, color: theme.colors.text, allowFontScaling: !disableScaling })));
    }, [items, children, styles, defaultStyles, collapseIcon, expanded, expandIcon]);
    const actionComponent = getActionComponent();
    const getChildren = (0, react_1.useCallback)(() => (0, utilities_1.findChildByType)(children, ['DrawerNavItem'])
        // .slice(0, 1)
        .map((child) => react_1.default.cloneElement(child, {
        ...(0, utilities_1.inheritSharedProps)(props, child.props),
        depth: depth + 1,
        isInActiveTree: activeHierarchy.includes(child.props.itemID),
        notifyActiveParent: (ids = []) => {
            notifyActiveParent(ids.concat(itemID));
        },
    })), [props, activeHierarchy]);
    const infoListItemStyles = styles.infoListItem || {};
    const { root: iliRoot, title: iliTitle, statusStripe: iliStatusStripe, ...otherILI } = infoListItemStyles;
    return (react_1.default.createElement(react_1.default.Fragment, null, !hidden && (react_1.default.createElement(react_1.default.Fragment, null,
        react_1.default.createElement(react_native_1.View, { style: [defaultStyles.root, styles.root] },
            active && react_1.default.createElement(react_native_1.View, { style: [defaultStyles.activeBackground, styles.activeBackground] }),
            react_1.default.createElement(info_list_item_1.InfoListItem, { dense: true, title: itemTitle, subtitle: itemSubtitle, divider: showDivider ? 'full' : undefined, statusColor: statusColor, fontColor: active ? activeItemFontColor : itemFontColor, icon: icon, iconColor: active ? activeItemIconColor : itemIconColor, rightComponent: (actionComponent || rightComponent) && (react_1.default.createElement(react_native_1.View, { style: { flexDirection: 'row', alignItems: 'center' } },
                    rightComponent,
                    actionComponent)), backgroundColor: 'transparent', onPress: hasAction ? onPressAction : undefined, hidePadding: hidePadding, styles: {
                    root: Object.assign({ paddingLeft: calcNestedPadding(depth, insets) }, iliRoot),
                    title: Object.assign(active || (isInActiveTree && !disableActiveItemParentStyles)
                        ? {
                            fontWeight: theme.fonts.medium.fontWeight,
                            fontFamily: theme.fonts.medium.fontFamily,
                        }
                        : {
                            fontWeight: theme.fonts.regular.fontWeight,
                            fontFamily: theme.fonts.regular.fontFamily,
                        }, iliTitle),
                    statusStripe: Object.assign({ left: insets.left }, iliStatusStripe),
                    ...otherILI,
                } })),
        ((items && items.length > 0) || Boolean(children)) && (react_1.default.createElement(react_native_collapsible_1.default, { collapsed: !expanded },
            items &&
                items.map((subItem, index) => (react_1.default.createElement(exports.DrawerNavItem, { key: `itemList_${index}`, ...subItem, ...(0, utilities_1.inheritSharedProps)(props, subItem), depth: depth + 1, isInActiveTree: activeHierarchy.includes(subItem.itemID), notifyActiveParent: (ids = []) => {
                        notifyActiveParent(ids.concat(itemID));
                    } }))),
            getChildren()))))));
};
exports.DrawerNavItem = DrawerNavItem;
exports.DrawerNavItem.displayName = 'DrawerNavItem';
