"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.EmptyState = void 0;
const react_1 = __importStar(require("react"));
const react_native_1 = require("react-native");
const react_native_paper_1 = require("react-native-paper");
const typography_1 = require("../typography");
const icon_1 = require("../icon");
const font_scale_context_1 = require("../__contexts__/font-scale-context");
const makeStyles = (theme, fontScale) => react_native_1.StyleSheet.create({
    root: {
        flex: 1,
        justifyContent: 'center',
        alignItems: 'center',
        padding: 16,
    },
    title: {
        textAlign: 'center',
        marginTop: 16 * fontScale,
    },
    description: {
        color: (theme.dark ? theme.colors.textPalette?.secondary : theme.colors.textPalette?.primary) ||
            theme.colors.text,
        textAlign: 'center',
    },
    actions: {
        marginTop: 16 * fontScale,
    },
});
/**
 * [EmptyState](https://brightlayer-ui-components.github.io/react-native/?path=/info/components-documentation--empty-state) component
 *
 * Used as a placeholder when no content is available for a particular area/screen in your application.
 * It displays an icon with up to two lines of text and has an area for you to add custom actionable content or
 * calls-to-action.
 */
const EmptyState = (props) => {
    const { title, description, actions, icon, iconColor, iconSize, styles = {}, style, theme: themeOverride, ...viewProps } = props;
    const theme = (0, react_native_paper_1.useTheme)(themeOverride);
    const fontScale = (0, font_scale_context_1.useFontScale)();
    const defaultStyles = makeStyles(theme, fontScale);
    const normalizeIconSize = (0, react_1.useCallback)(() => {
        if (!iconSize)
            return 100;
        return Math.max(100, Math.min(200, iconSize));
    }, [iconSize]);
    const getColor = (0, react_1.useCallback)((color) => color || theme.colors.textPalette?.secondary || theme.colors.textPalette?.primary || theme.colors.text, [theme]);
    const getIcon = (0, react_1.useCallback)(() => {
        if (icon) {
            return react_1.default.createElement(icon_1.Icon, { source: icon, size: normalizeIconSize(), color: getColor(iconColor) });
        }
    }, [icon, normalizeIconSize, getColor, iconColor]);
    return (react_1.default.createElement(react_native_1.View, { style: [defaultStyles.root, styles.root, style], ...viewProps },
        getIcon(),
        react_1.default.createElement(typography_1.H6, { style: [defaultStyles.title, styles.title] }, title),
        description ? (react_1.default.createElement(typography_1.Subtitle2, { style: [defaultStyles.description, styles.description] }, description)) : null,
        actions ? react_1.default.createElement(react_native_1.View, { style: [defaultStyles.actions, styles.actions] }, actions) : null));
};
exports.EmptyState = EmptyState;
