"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useColor = exports.ColorContext = void 0;
const react_1 = require("react");
exports.ColorContext = (0, react_1.createContext)(null);
/**
 * useColor hook
 *
 * This hook will provide you with the current text color value that is set at the top level
 * of the Header component. We expose this through a Context in order to avoid passing this prop
 * through every layer of the component hierarchy. This hook can only be called from within a
 * ColorContext.Provider.
 */
const useColor = () => {
    const context = (0, react_1.useContext)(exports.ColorContext);
    if (context === null) {
        throw new Error('useColor must be used within a ColorContextProvider');
    }
    return context;
};
exports.useColor = useColor;
