"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useHeaderHeight = exports.HeaderHeightContext = void 0;
const react_1 = require("react");
exports.HeaderHeightContext = (0, react_1.createContext)(null);
/**
 * useHeaderHeight hook
 *
 * This hook will provide you with the current height of the Header component. We expose this through a Context in order to avoid passing this prop
 * through every layer of the component hierarchy. This hook can only be called from within a
 * HeaderHeightContext.Provider.
 */
const useHeaderHeight = () => {
    const context = (0, react_1.useContext)(exports.HeaderHeightContext);
    if (context === null) {
        throw new Error('useHeaderHeight must be used within a HeaderHeightContextProvider');
    }
    return context;
};
exports.useHeaderHeight = useHeaderHeight;
