"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useSearch = exports.SearchContext = void 0;
const react_1 = require("react");
exports.SearchContext = (0, react_1.createContext)(null);
/**
 * useSearch hook
 *
 * This hook will provide you with the current searchConfig that is set at the top level
 * of the Header component. We expose this through a Context in order to avoid passing this prop
 * through every layer of the component hierarchy. This hook can only be called from within a
 * SearchContext.Provider.
 */
const useSearch = () => {
    const context = (0, react_1.useContext)(exports.SearchContext);
    if (context === null) {
        throw new Error('useSearch must be used within a SearchContextProvider');
    }
    return context;
};
exports.useSearch = useSearch;
