"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.HeaderBackgroundImage = void 0;
const react_1 = __importDefault(require("react"));
const react_native_1 = require("react-native");
const SearchContextProvider_1 = require("./contexts/SearchContextProvider");
const HeaderHeightContextProvider_1 = require("./contexts/HeaderHeightContextProvider");
const useHeaderDimensions_1 = require("../__hooks__/useHeaderDimensions");
const defaultStyles = (deviceWidth) => react_native_1.StyleSheet.create({
    root: {
        position: 'absolute',
        top: 0,
        left: 0,
        right: 0,
        bottom: 0,
        resizeMode: 'cover',
        width: deviceWidth,
    },
});
/**
 * HeaderBackgroundImage component
 *
 * The HeaderBackgroundImage is a helper component for organizing the contents in the Header. It is
 * used for displaying the background image and blending it with the background color.
 */
const HeaderBackgroundImage = (props) => {
    const { backgroundImage, style, ...otherImageProps } = props;
    const { searching } = (0, SearchContextProvider_1.useSearch)();
    const { headerHeight } = (0, HeaderHeightContextProvider_1.useHeaderHeight)();
    const { width } = react_native_1.Dimensions.get('screen');
    const { REGULAR_HEIGHT, EXTENDED_HEIGHT } = (0, useHeaderDimensions_1.useHeaderDimensions)();
    if (backgroundImage && !searching) {
        return (react_1.default.createElement(react_native_1.Animated.Image, { testID: 'header-background-image', resizeMethod: 'resize', ...otherImageProps, source: backgroundImage, style: [
                defaultStyles(width).root,
                style,
                {
                    height: headerHeight,
                    opacity: headerHeight.interpolate({
                        inputRange: [REGULAR_HEIGHT, EXTENDED_HEIGHT],
                        outputRange: [0.2, 0.3],
                    }),
                },
            ] }));
    }
    return null;
};
exports.HeaderBackgroundImage = HeaderBackgroundImage;
