"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.HeaderContent = void 0;
const react_1 = __importStar(require("react"));
const react_native_1 = require("react-native");
const color_1 = __importDefault(require("color"));
const constants_1 = require("./constants");
const SearchContextProvider_1 = require("./contexts/SearchContextProvider");
const ColorContextProvider_1 = require("./contexts/ColorContextProvider");
const HeaderHeightContextProvider_1 = require("./contexts/HeaderHeightContextProvider");
const useHeaderDimensions_1 = require("../__hooks__/useHeaderDimensions");
const font_scale_context_1 = require("../__contexts__/font-scale-context");
const headerContentStyles = react_native_1.StyleSheet.create({
    titleContainer: {
        flex: 1,
        flexDirection: 'column',
        justifyContent: 'flex-end',
    },
    searchContainer: {
        flex: 1,
        flexDirection: 'column',
        justifyContent: 'center',
        marginRight: 56,
        marginTop: 0,
    },
});
/**
 * HeaderTitle component
 *
 * The HeaderTitle is a helper component for organizing the contents in the Header. It is
 * used for displaying and resizing the title text.
 */
const HeaderTitle = (props) => {
    const { title, theme, style } = props;
    const { color: textColor } = (0, ColorContextProvider_1.useColor)();
    const { headerHeight } = (0, HeaderHeightContextProvider_1.useHeaderHeight)();
    const { REGULAR_HEIGHT, EXTENDED_HEIGHT } = (0, useHeaderDimensions_1.useHeaderDimensions)();
    const { maxScale, minScale, disableScaling } = (0, font_scale_context_1.useFontScaleSettings)();
    const getTitleStyle = (0, react_1.useCallback)(() => ({
        color: textColor,
        fontFamily: theme.fonts.medium.fontFamily,
        fontSize: headerHeight.interpolate({
            inputRange: [REGULAR_HEIGHT, EXTENDED_HEIGHT],
            outputRange: [20, 30],
            extrapolate: 'clamp',
        }),
        writingDirection: react_native_1.I18nManager.isRTL ? 'rtl' : 'ltr',
        textAlign: react_native_1.Platform.OS === 'android' ? 'left' : 'auto',
    }), [textColor, headerHeight, theme, REGULAR_HEIGHT, EXTENDED_HEIGHT]);
    return typeof title === 'string' ? (react_1.default.createElement(react_native_1.Animated.Text, { testID: 'header-title', style: [getTitleStyle(), style], numberOfLines: 1, ellipsizeMode: 'tail', allowFontScaling: !disableScaling, maxFontSizeMultiplier: maxScale, minimumFontScale: minScale }, title)) : (react_1.default.createElement(react_1.default.Fragment, null, title));
};
/**
 * HeaderSubtitle component
 *
 * The HeaderSubtitle is a helper component for organizing the contents in the Header. It is
 * used for displaying and resizing the subtitle text.
 */
const HeaderSubtitle = (props) => {
    const { subtitle, theme, style, washingtonStyle } = props;
    const { color: textColor } = (0, ColorContextProvider_1.useColor)();
    const { maxScale, minScale, disableScaling } = (0, font_scale_context_1.useFontScaleSettings)();
    const getSubtitleStyle = (0, react_1.useCallback)(() => ({
        color: textColor,
        fontFamily: washingtonStyle ? theme.fonts.light.fontFamily : theme.fonts.regular.fontFamily,
        fontSize: washingtonStyle ? 18 : 16,
        writingDirection: react_native_1.I18nManager.isRTL ? 'rtl' : 'ltr',
        textAlign: react_native_1.Platform.OS === 'android' ? 'left' : 'auto',
    }), [textColor, theme, washingtonStyle]);
    if (subtitle) {
        return typeof subtitle === 'string' ? (react_1.default.createElement(react_native_1.Animated.Text, { testID: 'header-subtitle', style: [getSubtitleStyle(), style], numberOfLines: 1, ellipsizeMode: 'tail', allowFontScaling: !disableScaling, maxFontSizeMultiplier: maxScale, minimumFontScale: minScale }, subtitle)) : (react_1.default.createElement(react_1.default.Fragment, null, subtitle));
    }
    return null;
};
/**
 * HeaderInfo component
 *
 * The HeaderInfo is a helper component for organizing the contents in the Header. It is
 * used for displaying and resizing the info text.
 */
const HeaderInfo = (props) => {
    const { info, theme, style } = props;
    const { color: textColor } = (0, ColorContextProvider_1.useColor)();
    const { headerHeight } = (0, HeaderHeightContextProvider_1.useHeaderHeight)();
    const { maxScale, minScale, disableScaling } = (0, font_scale_context_1.useFontScaleSettings)();
    const fontScale = (0, font_scale_context_1.useFontScale)();
    const { REGULAR_HEIGHT, EXTENDED_HEIGHT } = (0, useHeaderDimensions_1.useHeaderDimensions)();
    const getInfoStyle = (0, react_1.useCallback)(() => ({
        color: textColor,
        marginTop: headerHeight.interpolate({
            inputRange: [REGULAR_HEIGHT, EXTENDED_HEIGHT],
            outputRange: [-2 * fontScale, 0],
            extrapolate: 'clamp',
        }),
        opacity: headerHeight.interpolate({
            inputRange: [REGULAR_HEIGHT, EXTENDED_HEIGHT],
            outputRange: [0, 1],
            extrapolate: 'clamp',
        }),
        fontFamily: theme.fonts.regular.fontFamily,
        fontSize: headerHeight.interpolate({
            inputRange: [REGULAR_HEIGHT, EXTENDED_HEIGHT],
            outputRange: [0.1, 20],
            extrapolate: 'clamp',
        }),
        writingDirection: react_native_1.I18nManager.isRTL ? 'rtl' : 'ltr',
        textAlign: react_native_1.Platform.OS === 'android' ? 'left' : 'auto',
    }), [textColor, theme, headerHeight, REGULAR_HEIGHT, EXTENDED_HEIGHT, fontScale]);
    if (info) {
        return typeof info === 'string' ? (react_1.default.createElement(react_native_1.Animated.Text, { testID: 'header-info', style: [getInfoStyle(), style], numberOfLines: 1, ellipsizeMode: 'tail', allowFontScaling: !disableScaling, maxFontSizeMultiplier: maxScale, minimumFontScale: minScale }, info)) : (react_1.default.createElement(react_1.default.Fragment, null, info));
    }
    return null;
};
/**
 * SearchContent component
 *
 * The SearchContent is a helper component for organizing the contents in the Header. It is
 * used for displaying and styling the search input. It retrieves the search configuration via
 * the useSearch hook.
 */
const SearchContent = (props) => {
    const { theme, style } = props;
    const { searchConfig = {}, onQueryChange, searchRef } = (0, SearchContextProvider_1.useSearch)();
    const { color: textColor } = (0, ColorContextProvider_1.useColor)();
    const { maxScale, disableScaling } = (0, font_scale_context_1.useFontScaleSettings)();
    const placeholderTextColor = (0, color_1.default)(textColor).fade(0.4).string();
    return (react_1.default.createElement(react_native_1.TextInput, { key: 'search-input', ref: searchRef, style: [
            {
                padding: 0,
                color: textColor,
                fontSize: 20,
                ...theme.fonts.light,
            },
            style,
        ], autoCapitalize: searchConfig.autoCapitalize || 'none', autoCorrect: searchConfig.autoCorrect || false, autoFocus: searchConfig.autoFocus, numberOfLines: 1, onChangeText: onQueryChange, placeholder: searchConfig.placeholder || 'Search', placeholderTextColor: placeholderTextColor, returnKeyType: 'search', selectionColor: placeholderTextColor, underlineColorAndroid: 'transparent', allowFontScaling: !disableScaling, maxFontSizeMultiplier: maxScale }));
};
/**
 * HeaderContent component
 *
 * The HeaderContent is a helper component for organizing the contents in the Header. It is
 * a wrapper that organizes the title, subtitle, info, and search inputs appropriately.
 */
const HeaderContent = (props) => {
    const { title, subtitle, info, actions = { components: { count: 0, width: 0 }, icons: { count: 0 } }, theme, styles = {}, washingtonStyle, } = props;
    const { headerHeight } = (0, HeaderHeightContextProvider_1.useHeaderHeight)();
    const { searching, searchConfig } = (0, SearchContextProvider_1.useSearch)();
    const fontScale = (0, font_scale_context_1.useFontScale)();
    const defaultStyles = headerContentStyles;
    const { REGULAR_HEIGHT, EXTENDED_HEIGHT } = (0, useHeaderDimensions_1.useHeaderDimensions)();
    let content = [];
    if (searchConfig && searching) {
        content = [react_1.default.createElement(SearchContent, { key: 'search-content', theme: theme, style: styles.search })];
    }
    else {
        content = [
            react_1.default.createElement(HeaderTitle, { title: title, key: "title_key", theme: theme, style: [styles.title] }),
            react_1.default.createElement(HeaderInfo, { info: info, key: "info_key", theme: theme, style: [styles.info] }),
            react_1.default.createElement(HeaderSubtitle, { subtitle: subtitle, key: "subtitle_key", theme: theme, style: [styles.subtitle], washingtonStyle: washingtonStyle }),
        ];
    }
    const getActionPanelWidth = (0, react_1.useCallback)(() => {
        let iconLength = actions.icons.count;
        const componentsLength = actions.components.count;
        const componentsWidth = actions.components.width;
        if (searchConfig)
            iconLength++;
        if (iconLength + componentsLength < 1)
            return 0;
        return iconLength * (constants_1.ICON_SIZE * fontScale + constants_1.ICON_SPACING) + componentsWidth;
    }, [actions, searchConfig, fontScale]);
    return (react_1.default.createElement(react_native_1.Animated.View, { style: [
            searching ? defaultStyles.searchContainer : defaultStyles.titleContainer,
            searching
                ? {}
                : {
                    marginRight: headerHeight.interpolate({
                        inputRange: [REGULAR_HEIGHT, EXTENDED_HEIGHT],
                        outputRange: [getActionPanelWidth(), 0],
                        extrapolate: 'clamp',
                    }),
                    marginBottom: subtitle && title ? 5 * fontScale : 15 * fontScale,
                },
            styles.root,
        ] },
        react_1.default.createElement(react_native_1.View, { style: { flex: 0, justifyContent: 'center' } }, content)));
};
exports.HeaderContent = HeaderContent;
