"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Hero = void 0;
const react_1 = __importStar(require("react"));
const react_native_1 = require("react-native");
const channel_value_1 = require("../channel-value");
const react_native_paper_1 = require("react-native-paper");
const typography_1 = require("../typography");
const icon_1 = require("../icon");
const font_scale_context_1 = require("../__contexts__/font-scale-context");
const makeStyles = (fontScale) => react_native_1.StyleSheet.create({
    root: {
        flex: 1,
        alignItems: 'center',
        justifyContent: 'center',
        paddingHorizontal: 8,
        paddingVertical: 16,
    },
    iconWrapper: {
        padding: 0,
        marginBottom: 4 * fontScale,
        alignItems: 'center',
        justifyContent: 'center',
        overflow: 'hidden',
        height: 48 * fontScale,
        width: 48 * fontScale,
        borderRadius: 24 * fontScale,
    },
    values: {
        flexDirection: 'row',
        justifyContent: 'center',
        alignItems: 'center',
        maxWidth: '100%',
    },
    label: {
        width: '100%',
        overflow: 'hidden',
        textAlign: 'center',
    },
});
/**
 * [Hero](https://brightlayer-ui-components.github.io/react-native/?path=/info/components-documentation--hero) component
 *
 * The Hero is used to call attention to particular values of importance to the user. It includes a
 * large icon with a label and (typically) a [ChannelValue](https://brightlayer-ui-components.github.io/react-native/?path=/info/components-documentation--channel-value) item. The channel value can be configured
 * through the `ChannelValueProps`, or passed declaratively as a child.
 */
const Hero = (props) => {
    const { label, ChannelValueProps, onPress, icon, iconColor, iconSize, iconBackgroundColor, children, styles = {}, style, theme: themeOverride, ...viewProps } = props;
    const theme = (0, react_native_paper_1.useTheme)(themeOverride);
    const fontScale = (0, font_scale_context_1.useFontScale)();
    const defaultStyles = makeStyles(fontScale);
    const normalizeIconSize = (0, react_1.useCallback)(() => {
        if (!iconSize)
            return 36;
        return Math.max(10, Math.min(48, iconSize));
    }, [iconSize]);
    const getColor = (0, react_1.useCallback)((color) => color || theme.colors.text, [theme]);
    const getIcon = (0, react_1.useCallback)(() => {
        if (icon) {
            return react_1.default.createElement(icon_1.Icon, { source: icon, size: normalizeIconSize(), color: getColor(iconColor) });
        }
    }, [icon, normalizeIconSize, getColor, iconColor]);
    return (react_1.default.createElement(react_native_1.TouchableOpacity, { onPress: onPress, disabled: !onPress, style: [defaultStyles.root, styles.root, style], ...viewProps },
        react_1.default.createElement(react_native_1.View, { style: [
                defaultStyles.iconWrapper,
                { backgroundColor: iconBackgroundColor || theme.colors.surface },
                styles.iconWrapper,
            ] }, getIcon()),
        react_1.default.createElement(react_native_1.View, { style: [defaultStyles.values, styles.values] },
            !children && !!ChannelValueProps?.value && react_1.default.createElement(channel_value_1.ChannelValue, { fontSize: 20, ...ChannelValueProps }),
            children),
        react_1.default.createElement(typography_1.Body1, { style: [defaultStyles.label, styles.label], numberOfLines: 1, ellipsizeMode: 'tail' }, label)));
};
exports.Hero = Hero;
