"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.wrapIcon = void 0;
const react_1 = __importDefault(require("react"));
const font_scale_context_1 = require("../__contexts__/font-scale-context");
const isIconSetArg = (x) => x.name !== undefined;
/**
 * [wrapIcon](https://brightlayer-ui-components.github.io/react-native/?path=/info/components-documentation--icon-wrapper) function
 *
 * This function is a useful utility for making sure that icons you want to use
 * are in the proper form to be consumed by the Brightlayer UI components. Icons used by the
 * Brightlayer UI components must have the shape ({size, color}) => JSX.Element;
 *
 * This function can wrap SVG files or icons from react-native-vector-icons.
 *
 * @param arg an object representing the icon you wish to render
 * @returns A Component function that properly matches the expected icon shape
 */
const wrapIcon = (arg) => {
    const flipIcon = {
        transform: [{ scaleX: -1 }],
    };
    const { allowFontScaling = true, flip = false } = arg;
    // If it is a react-native-vector icon
    if (isIconSetArg(arg)) {
        const { name, IconClass } = arg;
        // eslint-disable-next-line react/display-name
        return (props) => {
            const { allowFontScaling: inlineScaling = allowFontScaling, size, color } = props;
            return (react_1.default.createElement(IconClass, { name: name, color: color, size: size, allowFontScaling: inlineScaling, testID: 'icon', style: flip ? flipIcon : {} }));
        };
    }
    // If it is a Brightlayer UI icon
    const { IconClass } = arg;
    // eslint-disable-next-line react/display-name
    return (props) => {
        const { allowFontScaling: inlineScaling = allowFontScaling, size, color } = props;
        const fontScale = (0, font_scale_context_1.useFontScale)(inlineScaling);
        return (react_1.default.createElement(IconClass, { fill: color, width: size * fontScale, height: size * fontScale, testID: 'icon', style: flip ? flipIcon : {} }));
    };
};
exports.wrapIcon = wrapIcon;
