"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ScoreCard = void 0;
const react_1 = __importStar(require("react"));
const react_native_1 = require("react-native");
const Typography = __importStar(require("../typography"));
const react_native_paper_1 = require("react-native-paper");
const icon_1 = require("../icon");
const font_scale_context_1 = require("../__contexts__/font-scale-context");
const backgroundImageStyles = react_native_1.StyleSheet.create({
    root: {
        position: 'absolute',
        width: '100%',
        resizeMode: 'cover',
        height: '100%',
        opacity: 0.1,
    },
});
/**
 * BackgroundImage component
 *
 * This is a utility sub-component used to organize content in the ScoreCard. It
 * is responsible for laying out and styling the optional background image.
 */
const BackgroundImage = (props) => {
    const { headerBackgroundImage, style } = props;
    const defaultStyles = backgroundImageStyles;
    if (headerBackgroundImage) {
        return (react_1.default.createElement(react_native_1.Image, { testID: 'header-background-image', source: headerBackgroundImage, style: [defaultStyles.root, style] }));
    }
    return null;
};
/**
 * HeaderText component
 *
 * This is a utility sub-component used to organize content in the ScoreCard. It
 * is responsible for laying out and styling the text elements in the header.
 */
const HeaderText = (props) => {
    const { title, subtitle, info, color, styles = {} } = props;
    const textColor = color || 'white';
    return (react_1.default.createElement(react_native_1.View, { style: [{ flex: 1 }, styles.root] },
        react_1.default.createElement(Typography.H6, { testID: 'header_title', style: [{ color: textColor }, styles.title], font: 'medium', numberOfLines: 1, ellipsizeMode: 'tail' }, title),
        subtitle ? (react_1.default.createElement(Typography.Subtitle2, { testID: 'header_subtitle', style: [{ color: textColor }, styles.subtitle], font: 'regular', numberOfLines: 1, ellipsizeMode: 'tail' }, subtitle)) : null,
        info ? (react_1.default.createElement(Typography.Subtitle2, { testID: 'header_info', style: [{ color: textColor }, styles.info], font: 'light', numberOfLines: 1, ellipsizeMode: 'tail' }, info)) : null));
};
/**
 * Footer component
 *
 * This is a utility sub-component used to organize content in the ScoreCard. It
 * is responsible for laying out and styling the action row / footer.
 */
const Footer = (props) => {
    const { actionRow, style } = props;
    if (actionRow) {
        return (react_1.default.createElement(react_1.default.Fragment, null,
            react_1.default.createElement(react_native_paper_1.Divider, null),
            react_1.default.createElement(react_native_1.View, { style: [style] }, actionRow)));
    }
    return null;
};
/**
 * HeroPanel component
 *
 * This is a utility sub-component used to organize content in the ScoreCard. It
 * is responsible for laying out and styling the badge content (typically a Hero or Heroes).
 */
const HeroPanel = (props) => {
    const { badge, badgeOffset = 0, style } = props;
    if (badge) {
        return react_1.default.createElement(react_native_1.View, { style: [{ flex: 0, marginTop: badgeOffset }, style] }, badge);
    }
    return null;
};
const actionPanelStyles = (fontScale) => react_native_1.StyleSheet.create({
    root: {
        flexDirection: 'row',
        margin: -8 * fontScale,
    },
    actionItem: {
        // vertical padding scales with fontSize, horizontal padding is fixed
        height: 40 * fontScale,
        width: 24 * fontScale + 16,
        paddingHorizontal: 8,
        paddingVertical: 8 * fontScale,
    },
});
/**
 * ActionPanel component
 *
 * This is a utility sub-component used to organize content in the ScoreCard. It
 * is responsible for laying out and styling the action item icons.
 */
const ActionPanel = (props) => {
    const { actionItems, color = 'white', styles = {} } = props;
    const fontScale = (0, font_scale_context_1.useFontScale)();
    const defaultStyles = actionPanelStyles(fontScale);
    const getIcon = (0, react_1.useCallback)(
    // eslint-disable-next-line @typescript-eslint/naming-convention
    (icon) => {
        if (icon) {
            return react_1.default.createElement(icon_1.Icon, { source: icon, size: 24, color: color });
        }
    }, [color]);
    if (actionItems) {
        return (react_1.default.createElement(react_native_1.View, { style: [defaultStyles.root, styles.root] }, actionItems.slice(0, 6).map((actionItem, index) => (react_1.default.createElement(react_native_1.TouchableOpacity, { key: `${index}`, testID: `action-item${index}`, onPress: actionItem.onPress, style: [defaultStyles.actionItem, styles.actionItem] }, getIcon(actionItem.icon))))));
    }
    return null;
};
const scoreCardStyles = (theme, props, fontScale) => react_native_1.StyleSheet.create({
    root: {
        flex: 1,
    },
    header: {
        height: 100 * fontScale,
        overflow: 'hidden',
        backgroundColor: props.headerColor || theme.colors.primary,
        borderTopLeftRadius: theme.roundness,
        borderTopRightRadius: theme.roundness,
    },
    headerContent: {
        flexDirection: 'row',
        alignItems: 'flex-start',
        padding: 16,
    },
    padded: {
        padding: 16,
    },
    body: {
        flexDirection: 'row',
        alignItems: 'stretch',
        padding: 16,
    },
    leftContent: {
        flex: 1,
        justifyContent: 'center',
        marginRight: props.badge ? 16 : 0,
    },
});
/**
 * [ScoreCard](https://brightlayer-ui-components.github.io/react-native/?path=/info/components-documentation--score-card) component
 *
 * This component renders a "score card" which is typically used in dashboard
 * displays to show the status of individual items along with some details.
 * The header is configurable with various text elements and icon actions and the
 * main body is fully customizable. You can use the `badge` prop to supply elements
 * that can span between the header and the body, such as a [Hero](https://brightlayer-ui-components.github.io/react-native/?path=/info/components-documentation--hero) with a grade icon.
 */
const ScoreCard = (props) => {
    const { theme: themeOverride, ...otherProps } = props;
    const theme = (0, react_native_paper_1.useTheme)(themeOverride);
    const { actionRow, actionItems, badge, badgeOffset, children, headerBackgroundImage, headerColor, // eslint-disable-line @typescript-eslint/no-unused-vars
    headerTitle, headerSubtitle, headerInfo, headerFontColor, styles = {}, style, ...cardProps } = otherProps;
    const fontScale = (0, font_scale_context_1.useFontScale)();
    const defaultStyles = scoreCardStyles(theme, props, fontScale);
    return (
    // @ts-ignore bad types from RNP
    react_1.default.createElement(react_native_paper_1.Card, { elevation: 1, style: [defaultStyles.root, styles.root, style], ...cardProps },
        react_1.default.createElement(react_native_1.View, { style: [defaultStyles.header, styles.header] },
            react_1.default.createElement(BackgroundImage, { headerBackgroundImage: headerBackgroundImage, style: styles.backgroundImage }),
            react_1.default.createElement(react_native_1.View, { style: [defaultStyles.padded, defaultStyles.headerContent, styles.headerContent] },
                react_1.default.createElement(HeaderText, { title: headerTitle, subtitle: headerSubtitle, info: headerInfo, color: headerFontColor, styles: {
                        root: styles.headerText,
                        title: styles.title,
                        subtitle: styles.subtitle,
                        info: styles.info,
                    } }),
                react_1.default.createElement(ActionPanel, { actionItems: actionItems, color: headerFontColor, styles: {
                        root: styles.headerActions,
                        actionItem: styles.headerActionItem,
                    } }))),
        react_1.default.createElement(react_native_1.View, { style: [defaultStyles.body, styles.body] },
            react_1.default.createElement(react_native_1.View, { style: [defaultStyles.leftContent, styles.leftContent] }, children),
            react_1.default.createElement(HeroPanel, { badge: badge, badgeOffset: badgeOffset, style: styles.badge })),
        react_1.default.createElement(Footer, { actionRow: actionRow, style: styles.actionRow })));
};
exports.ScoreCard = ScoreCard;
