import React from 'react';
import { TextProps, TextStyle, StyleProp } from 'react-native';
import { $DeepPartial } from '@callstack/react-theme-provider';
export declare type TypographyProps = {
    /**
     * The font size to use
     */
    fontSize?: number;
    /**
     * The font style to use (from the predefined values in the Theme)
     */
    font?: keyof ReactNativePaper.Theme['fonts'];
    /**
     * The color to use for the text (from the predefined values in the Theme or custom)
     */
    color?: string;
    /** Style overrides for internal elements. The styles you provide will be combined with the default styles. */
    styles?: {
        root?: StyleProp<TextStyle>;
    };
    /**
     * Theme value overrides specific to this component.
     */
    theme?: $DeepPartial<ReactNativePaper.Theme>;
} & TextProps;
/**
 * [H1](https://brightlayer-ui-components.github.io/react-native/?path=/info/components-documentation--typography) component
 *
 * An H1 heading
 */
export declare const H1: React.FC<TypographyProps>;
/**
 * [H2](https://brightlayer-ui-components.github.io/react-native/?path=/info/components-documentation--typography) component
 *
 * An H2 heading
 */
export declare const H2: React.FC<TypographyProps>;
/**
 * [H3](https://brightlayer-ui-components.github.io/react-native/?path=/info/components-documentation--typography) component
 *
 * An H3 heading
 */
export declare const H3: React.FC<TypographyProps>;
/**
 * [H4](https://brightlayer-ui-components.github.io/react-native/?path=/info/components-documentation--typography) component
 *
 * An H4 heading
 */
export declare const H4: React.FC<TypographyProps>;
/**
 * [H5](https://brightlayer-ui-components.github.io/react-native/?path=/info/components-documentation--typography) component
 *
 * An H5 heading
 */
export declare const H5: React.FC<TypographyProps>;
/**
 * [H6](https://brightlayer-ui-components.github.io/react-native/?path=/info/components-documentation--typography) component
 *
 * An H6 heading (used commonly for titles)
 */
export declare const H6: React.FC<TypographyProps>;
/**
 * [Body1](https://brightlayer-ui-components.github.io/react-native/?path=/info/components-documentation--typography) component
 *
 * A text component used for most body copy
 */
export declare const Body1: React.FC<TypographyProps>;
/**
 * [Body2](https://brightlayer-ui-components.github.io/react-native/?path=/info/components-documentation--typography) component
 *
 * A text component used for alternative body copy
 */
export declare const Body2: React.FC<TypographyProps>;
/**
 * [Label](https://brightlayer-ui-components.github.io/react-native/?path=/info/components-documentation--typography) component
 *
 * A secret, undocumented text component used for some labels in very specific places.
 *
 * Not intended for general use.
 */
export declare const Label: React.FC<TypographyProps>;
/**
 * [Subtitle1](https://brightlayer-ui-components.github.io/react-native/?path=/info/components-documentation--typography) component
 *
 * A subtitle component
 */
export declare const Subtitle1: React.FC<TypographyProps>;
/**
 * [Subtitle2](https://brightlayer-ui-components.github.io/react-native/?path=/info/components-documentation--typography) component
 *
 * An alternative subtitle component
 */
export declare const Subtitle2: React.FC<TypographyProps>;
/**
 * [Button](https://brightlayer-ui-components.github.io/react-native/?path=/info/components-documentation--typography) component
 *
 * A text component used for button labels
 */
export declare const Button: React.FC<TypographyProps>;
/**
 * [Caption](https://brightlayer-ui-components.github.io/react-native/?path=/info/components-documentation--typography) component
 *
 * A text component used for image captions
 */
export declare const Caption: React.FC<TypographyProps>;
/**
 * [Overline](https://brightlayer-ui-components.github.io/react-native/?path=/info/components-documentation--typography) component
 *
 * An all-caps text component used for specific labeling situations.
 */
export declare const Overline: React.FC<TypographyProps>;
