"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ThemedAppbar = void 0;
const react_1 = __importDefault(require("react"));
const react_native_paper_1 = require("react-native-paper");
const useAlternateTheme_1 = require("./hooks/useAlternateTheme");
/**
 * ThemedAppbar component
 *
 * This component is a wrapper around the React Native Paper [Appbar](https://callstack.github.io/react-native-paper/appbar.html)
 * component. It accepts all the same props as the RNP component. The wrapper simply performs some minor theme / style overrides
 * in order to make the component look the way we want for Brightlayer UI projects.
 */
const ThemedAppbar = (props) => {
    const { theme: themeOverride, ...other } = props;
    const theme = (0, useAlternateTheme_1.useAlternateTheme)(themeOverride);
    return react_1.default.createElement(react_native_paper_1.Appbar, { ...other, theme: theme });
};
exports.ThemedAppbar = ThemedAppbar;
