import React from 'react';
import { Checkbox } from 'react-native-paper';
export declare type ThemedCheckboxIOSProps = React.ComponentProps<typeof Checkbox.IOS>;
export declare type ThemedCheckboxAndroidProps = React.ComponentProps<typeof Checkbox.Android>;
export declare type ThemedCheckboxItemProps = React.ComponentProps<typeof Checkbox.Item>;
/**
 * ThemedCheckboxIOS component
 *
 * This component is a wrapper around the React Native Paper [Checkbox.IOS](https://callstack.github.io/react-native-paper/checkbox-ios.html)
 * component. It accepts all the same props as the RNP component. The wrapper simply performs some minor theme / style overrides
 * in order to make the component look the way we want for Brightlayer UI projects.
 */
export declare const ThemedCheckboxIOS: React.FC<ThemedCheckboxIOSProps>;
/**
 * ThemedCheckboxAndroid component
 *
 * This component is a wrapper around the React Native Paper [Checkbox.Android](https://callstack.github.io/react-native-paper/checkbox-android.html)
 * component. It accepts all the same props as the RNP component. The wrapper simply performs some minor theme / style overrides
 * in order to make the component look the way we want for Brightlayer UI projects.
 */
export declare const ThemedCheckboxAndroid: React.FC<ThemedCheckboxAndroidProps>;
/**
 * ThemedCheckbox component
 *
 * This component is a wrapper around the React Native Paper [Checkbox](https://callstack.github.io/react-native-paper/checkbox.html)
 * component. It accepts all the same props as the RNP component. The wrapper simply performs some minor theme / style overrides
 * in order to make the component look the way we want for Brightlayer UI projects.
 *
 * Note: We do not provide a wrapper around the `Checkbox.Item` component. This component from RNP uses the unstyled checkbox components
 * and unstyled text, so we do not recommend using it. If you wish to have this behavior, you should implement your own component making
 * use of the Brightlayer UI `Typography` components and the `ThemedCheckbox` provided here.
 */
export declare const ThemedCheckbox: React.FC<(Pick<import("react-native-paper").CheckboxProps, "color" | "onPress" | "testID" | "disabled" | "status" | "uncheckedColor"> & {
    theme?: import("@callstack/react-theme-provider").$DeepPartial<ReactNativePaper.Theme> | undefined;
}) | (Pick<import("react-native-paper").CheckboxProps, "color" | "onPress" | "testID" | "disabled" | "status" | "uncheckedColor"> & {
    theme?: import("@callstack/react-theme-provider").$DeepPartial<ReactNativePaper.Theme> | undefined;
} & {
    children?: React.ReactNode;
})> & {
    Android: React.FC<ThemedCheckboxAndroidProps>;
    IOS: React.FC<ThemedCheckboxIOSProps>;
};
