"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ThemedCheckbox = exports.ThemedCheckboxAndroid = exports.ThemedCheckboxIOS = void 0;
const react_1 = __importDefault(require("react"));
const react_native_1 = require("react-native");
const react_native_paper_1 = require("react-native-paper");
/**
 * ThemedCheckboxIOS component
 *
 * This component is a wrapper around the React Native Paper [Checkbox.IOS](https://callstack.github.io/react-native-paper/checkbox-ios.html)
 * component. It accepts all the same props as the RNP component. The wrapper simply performs some minor theme / style overrides
 * in order to make the component look the way we want for Brightlayer UI projects.
 */
const ThemedCheckboxIOS = (props) => {
    const { theme: themeOverride, color, ...other } = props;
    const theme = (0, react_native_paper_1.useTheme)(themeOverride);
    return (react_1.default.createElement(react_native_paper_1.Checkbox.IOS, { ...other, color: color || theme.colors.primaryPalette?.main || theme.colors.primary, theme: themeOverride }));
};
exports.ThemedCheckboxIOS = ThemedCheckboxIOS;
/**
 * ThemedCheckboxAndroid component
 *
 * This component is a wrapper around the React Native Paper [Checkbox.Android](https://callstack.github.io/react-native-paper/checkbox-android.html)
 * component. It accepts all the same props as the RNP component. The wrapper simply performs some minor theme / style overrides
 * in order to make the component look the way we want for Brightlayer UI projects.
 */
const ThemedCheckboxAndroid = (props) => {
    const { theme: themeOverride, color, uncheckedColor, ...other } = props;
    const theme = (0, react_native_paper_1.useTheme)(themeOverride);
    return (react_1.default.createElement(react_native_paper_1.Checkbox.Android, { ...other, uncheckedColor: uncheckedColor ||
            (props.status === 'unchecked'
                ? theme.colors.textPalette?.secondary || theme.colors.text
                : theme.colors.primaryPalette?.main || theme.colors.primary), color: color || theme.colors.primaryPalette?.main || theme.colors.primary, theme: themeOverride }));
};
exports.ThemedCheckboxAndroid = ThemedCheckboxAndroid;
const ThemedCheckboxComponent = (props) => react_native_1.Platform.OS === 'ios' ? react_1.default.createElement(exports.ThemedCheckboxIOS, { ...props }) : react_1.default.createElement(exports.ThemedCheckboxAndroid, { ...props });
/**
 * ThemedCheckbox component
 *
 * This component is a wrapper around the React Native Paper [Checkbox](https://callstack.github.io/react-native-paper/checkbox.html)
 * component. It accepts all the same props as the RNP component. The wrapper simply performs some minor theme / style overrides
 * in order to make the component look the way we want for Brightlayer UI projects.
 *
 * Note: We do not provide a wrapper around the `Checkbox.Item` component. This component from RNP uses the unstyled checkbox components
 * and unstyled text, so we do not recommend using it. If you wish to have this behavior, you should implement your own component making
 * use of the Brightlayer UI `Typography` components and the `ThemedCheckbox` provided here.
 */
exports.ThemedCheckbox = Object.assign(ThemedCheckboxComponent, {
    Android: exports.ThemedCheckboxAndroid,
    IOS: exports.ThemedCheckboxIOS,
});
