"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ThemedDivider = void 0;
const react_1 = __importDefault(require("react"));
const react_native_paper_1 = require("react-native-paper");
const useAlternateTheme_1 = require("./hooks/useAlternateTheme");
/**
 * ThemedDivider component
 *
 * This component is a wrapper around the React Native Paper [Divider](https://callstack.github.io/react-native-paper/divider.html)
 * component. It accepts all the same props as the RNP component. The wrapper simply performs some minor theme / style overrides
 * in order to make the component look the way we want for Brightlayer UI projects.
 */
const ThemedDivider = (props) => {
    const { theme: themeOverride, style, ...other } = props;
    const theme = (0, useAlternateTheme_1.useAlternateTheme)(themeOverride);
    const fullTheme = (0, react_native_paper_1.useTheme)(theme);
    const finalStyle = Object.assign({ backgroundColor: fullTheme.colors.divider }, style);
    return react_1.default.createElement(react_native_paper_1.Divider, { ...other, style: finalStyle, theme: theme });
};
exports.ThemedDivider = ThemedDivider;
