import React from 'react';
import { RadioButton } from 'react-native-paper';
export declare type ThemedRadioButtonIOSProps = React.ComponentProps<typeof RadioButton.IOS>;
export declare type ThemedRadioButtonAndroidProps = React.ComponentProps<typeof RadioButton.Android>;
export declare type ThemedRadioButtonItemProps = React.ComponentProps<typeof RadioButton.Item>;
/**
 * ThemedRadioButtonIOS component
 *
 * This component is a wrapper around the React Native Paper [RadioButton.IOS](https://callstack.github.io/react-native-paper/radio-button-ios.html)
 * component. It accepts all the same props as the RNP component. The wrapper simply performs some minor theme / style overrides
 * in order to make the component look the way we want for Brightlayer UI projects.
 */
export declare const ThemedRadioButtonIOS: React.FC<ThemedRadioButtonIOSProps>;
/**
 * ThemedRadioButtonAndroid component
 *
 * This component is a wrapper around the React Native Paper [RadioButton.Android](https://callstack.github.io/react-native-paper/radio-button-android.html)
 * component. It accepts all the same props as the RNP component. The wrapper simply performs some minor theme / style overrides
 * in order to make the component look the way we want for Brightlayer UI projects.
 */
export declare const ThemedRadioButtonAndroid: React.FC<ThemedRadioButtonAndroidProps>;
/**
 * ThemedRadioButton component
 *
 * This component is a wrapper around the React Native Paper [RadioButton](https://callstack.github.io/react-native-paper/radio-button.html)
 * component. It accepts all the same props as the RNP component. The wrapper simply performs some minor theme / style overrides
 * in order to make the component look the way we want for Brightlayer UI projects.
 *
 * Note: We do not provide a wrapper around the `RadioButton.Item` component. This component from RNP uses the unstyled RadioButton components
 * and unstyled text, so we do not recommend using it. If you wish to have this behavior, you should implement your own component making
 * use of the Brightlayer UI `Typography` components and the `ThemedRadioButton` provided here.
 */
export declare const ThemedRadioButton: React.FC<(Pick<import("react-native-paper").RadioButtonProps, "value" | "color" | "onPress" | "testID" | "disabled" | "status" | "uncheckedColor"> & {
    theme?: import("@callstack/react-theme-provider").$DeepPartial<ReactNativePaper.Theme> | undefined;
}) | (Pick<import("react-native-paper").RadioButtonProps, "value" | "color" | "onPress" | "testID" | "disabled" | "status" | "uncheckedColor"> & {
    theme?: import("@callstack/react-theme-provider").$DeepPartial<ReactNativePaper.Theme> | undefined;
} & {
    children?: React.ReactNode;
})> & {
    Android: React.FC<ThemedRadioButtonAndroidProps>;
    IOS: React.FC<ThemedRadioButtonIOSProps>;
    Group: React.FC<import("react-native-paper").RadioButtonGroupProps>;
};
