"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ThemedRadioButton = exports.ThemedRadioButtonAndroid = exports.ThemedRadioButtonIOS = void 0;
const react_1 = __importDefault(require("react"));
const react_native_1 = require("react-native");
const react_native_paper_1 = require("react-native-paper");
/**
 * ThemedRadioButtonIOS component
 *
 * This component is a wrapper around the React Native Paper [RadioButton.IOS](https://callstack.github.io/react-native-paper/radio-button-ios.html)
 * component. It accepts all the same props as the RNP component. The wrapper simply performs some minor theme / style overrides
 * in order to make the component look the way we want for Brightlayer UI projects.
 */
const ThemedRadioButtonIOS = (props) => {
    const { theme: themeOverride, color, ...other } = props;
    const theme = (0, react_native_paper_1.useTheme)(themeOverride);
    return (react_1.default.createElement(react_native_paper_1.RadioButton.IOS, { ...other, color: color || theme.colors.primaryPalette?.main || theme.colors.primary, theme: themeOverride }));
};
exports.ThemedRadioButtonIOS = ThemedRadioButtonIOS;
/**
 * ThemedRadioButtonAndroid component
 *
 * This component is a wrapper around the React Native Paper [RadioButton.Android](https://callstack.github.io/react-native-paper/radio-button-android.html)
 * component. It accepts all the same props as the RNP component. The wrapper simply performs some minor theme / style overrides
 * in order to make the component look the way we want for Brightlayer UI projects.
 */
const ThemedRadioButtonAndroid = (props) => {
    const { theme: themeOverride, color, uncheckedColor, ...other } = props;
    const theme = (0, react_native_paper_1.useTheme)(themeOverride);
    return (react_1.default.createElement(react_native_paper_1.RadioButton.Android, { ...other, uncheckedColor: uncheckedColor ||
            (props.status === 'unchecked'
                ? theme.colors.textPalette?.secondary || theme.colors.text
                : theme.colors.primaryPalette?.main || theme.colors.primary), color: color || theme.colors.primaryPalette?.main || theme.colors.primary, theme: themeOverride }));
};
exports.ThemedRadioButtonAndroid = ThemedRadioButtonAndroid;
const ThemedRadioButtonComponent = (props) => react_native_1.Platform.OS === 'ios' ? react_1.default.createElement(exports.ThemedRadioButtonIOS, { ...props }) : react_1.default.createElement(exports.ThemedRadioButtonAndroid, { ...props });
const ThemedRadioButtonGroup = (props) => (react_1.default.createElement(react_native_paper_1.RadioButton.Group, { ...props }));
/**
 * ThemedRadioButton component
 *
 * This component is a wrapper around the React Native Paper [RadioButton](https://callstack.github.io/react-native-paper/radio-button.html)
 * component. It accepts all the same props as the RNP component. The wrapper simply performs some minor theme / style overrides
 * in order to make the component look the way we want for Brightlayer UI projects.
 *
 * Note: We do not provide a wrapper around the `RadioButton.Item` component. This component from RNP uses the unstyled RadioButton components
 * and unstyled text, so we do not recommend using it. If you wish to have this behavior, you should implement your own component making
 * use of the Brightlayer UI `Typography` components and the `ThemedRadioButton` provided here.
 */
exports.ThemedRadioButton = Object.assign(ThemedRadioButtonComponent, {
    Android: exports.ThemedRadioButtonAndroid,
    IOS: exports.ThemedRadioButtonIOS,
    Group: ThemedRadioButtonGroup,
});
