"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ThemedSnackbar = void 0;
const react_1 = __importDefault(require("react"));
const react_native_paper_1 = require("react-native-paper");
const useAlternateTheme_1 = require("./hooks/useAlternateTheme");
/**
 * ThemedSnackbar component
 *
 * This component is a wrapper around the React Native Paper [Snackbar](https://callstack.github.io/react-native-paper/snackbar.html)
 * component. It accepts all the same props as the RNP component. The wrapper simply performs some minor theme / style overrides
 * in order to make the component look the way we want for Brightlayer UI projects.
 */
const ThemedSnackbar = (props) => {
    const { theme: themeOverride, ...other } = props;
    const currentTheme = (0, react_native_paper_1.useTheme)(themeOverride);
    const theme = (0, useAlternateTheme_1.useAlternateTheme)(themeOverride, { colors: { accent: currentTheme.colors.overrides?.snackbar?.accent || currentTheme.colors.accent } }, { colors: { accent: currentTheme.colors.primaryPalette?.dark || currentTheme.colors.primary } });
    const fullTheme = (0, react_native_paper_1.useTheme)(theme);
    return (react_1.default.createElement(react_native_paper_1.Provider, { theme: fullTheme },
        react_1.default.createElement(react_native_paper_1.Snackbar, { ...other, theme: theme })));
};
exports.ThemedSnackbar = ThemedSnackbar;
