"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ThemedSwitch = void 0;
const react_1 = __importDefault(require("react"));
const react_native_paper_1 = require("react-native-paper");
const BLUIColors = __importStar(require("@brightlayer-ui/colors"));
const color_1 = __importDefault(require("color"));
const react_native_1 = require("react-native");
const getTrackColor = (props, theme) => {
    const ios = react_native_1.Platform.OS === 'ios';
    const disabledAndroid = !ios && props.disabled;
    if (theme.dark) {
        return {
            true: ios
                ? theme.colors.primaryPalette?.main || theme.colors.primary
                : (0, color_1.default)(theme.colors.primaryPalette?.main || theme.colors.primary)
                    .alpha(props.disabled ? 0.25 : 0.5)
                    .string(),
            false: (0, color_1.default)(BLUIColors.black[300])
                .alpha(disabledAndroid ? 0.18 : 0.36)
                .string(),
        };
    }
    return {
        true: ios
            ? theme.colors.primaryPalette?.main || theme.colors.primary
            : (0, color_1.default)(theme.colors.primaryPalette?.main || theme.colors.primary)
                .alpha(props.disabled ? 0.19 : 0.38)
                .string(),
        false: (0, color_1.default)(BLUIColors.black[100])
            .alpha(disabledAndroid ? 0.19 : 0.38)
            .string(),
    };
};
const getThumbColor = (props, theme) => {
    if (react_native_1.Platform.OS === 'ios')
        return 'white';
    if (props.value)
        return (0, color_1.default)(theme.colors.primaryPalette?.main || theme.colors.primary)
            .mix((0, color_1.default)(theme.colors.surface), props.disabled ? 0.5 : 0)
            .string();
    return theme.dark
        ? (0, color_1.default)(BLUIColors.black[50])
            .mix((0, color_1.default)(theme.colors.surface), props.disabled ? 0.5 : 0)
            .string()
        : (0, color_1.default)('white')
            .mix((0, color_1.default)(theme.colors.surface), props.disabled ? 0.5 : 0)
            .string();
};
/**
 * ThemedSwitch component
 *
 * This component is a wrapper around the React Native Paper [Switch](https://callstack.github.io/react-native-paper/switch.html)
 * component. It accepts all the same props as the RNP component. The wrapper simply performs some minor theme / style overrides
 * in order to make the component look the way we want for Brightlayer UI projects.
 */
const ThemedSwitch = (props) => {
    const { color, theme: themeOverride } = props;
    const theme = (0, react_native_paper_1.useTheme)(themeOverride);
    return color ? (react_1.default.createElement(react_native_paper_1.Switch, { ...props })) : (react_1.default.createElement(react_native_paper_1.Switch, { ios_backgroundColor: 
        // disabled only
        theme.dark
            ? theme.colors.actionPalette?.disabled || theme.colors.disabled
            : (0, color_1.default)(BLUIColors.black[100]).alpha(0.38).string(), thumbColor: getThumbColor(props, theme), trackColor: getTrackColor(props, theme), ...props }));
};
exports.ThemedSwitch = ThemedSwitch;
